@@ -7,5 +7,8 @@ from esperclient.api.commands_v2_api import CommandsV2Api
 from esperclient.api.device_api import DeviceApi
 from esperclient.api.device_group_api import DeviceGroupApi
 from esperclient.api.enterprise_api import EnterpriseApi
+from esperclient.api.enterprise_policy_api import EnterprisePolicyApi
+from esperclient.api.geofence_api import GeofenceApi
 from esperclient.api.group_commands_api import GroupCommandsApi
+from esperclient.api.subscription_api import SubscriptionApi
 from esperclient.api.token_api import TokenApi
